==> s-render-0.1.6.tgz: package/lib/FormRender/widgets/container/BoxCard.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/FormRender/widgets/container/BoxCard.tsx
var BoxCard_exports = {};
__export(BoxCard_exports, {
  default: () => BoxCard_default
});
module.exports = __toCommonJS(BoxCard_exports);
var import_antd = require("antd");
var import_react = require("react");
var import_styled_components = require("styled-components");
var import_context = require("../../../FormRender/models/context");
var CardWrapper = (0, import_styled_components.styled)(import_antd.Card)`
  .ant-card-head {
    ${(props) => props["data-primary"] && import_styled_components.css`
        background-color: ${props["data-primary"]};
        color: #fff;
      `}
  }
  .ant-card-body {
    margin-bottom: -24px;
  }
`;
var BoxCard_default = (props) => {
  const { schema, renderCore, rootPath, path, children } = props;
  const { themeConfig } = (0, import_react.useContext)(import_context.ConfigContext);
  return /* @__PURE__ */ React.createElement(
    CardWrapper,
    {
      title: schema == null ? void 0 : schema.title,
      size: "small",
      "data-primary": themeConfig.colorPrimary
    },
    /* @__PURE__ */ React.createElement(import_antd.Row, { style: { marginTop: "24px" } }, children ? children : renderCore({
      schema: schema.properties,
      rootPath: [...rootPath, path]
    }))
  );
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});

==> s-render-0.1.9.tgz: package/lib/FormRender/widgets/container/BoxCard.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/FormRender/widgets/container/BoxCard.tsx
var BoxCard_exports = {};
__export(BoxCard_exports, {
  default: () => BoxCard_default
});
module.exports = __toCommonJS(BoxCard_exports);
var import_antd = require("antd");
var import_react = require("react");
var import_styled_components = require("styled-components");
var import_context = require("../../../FormRender/models/context");
var CardWrapper = (0, import_styled_components.styled)(import_antd.Card)`
  .ant-card-head {
    ${(props) => props["data-primary"] && import_styled_components.css`
        background-color: ${props["data-primary"]};
        color: #fff;
      `}
  }
  .ant-card-body {
    margin-bottom: -24px;
  }
`;
var BoxCard_default = (props) => {
  const { schema, renderCore, rootPath, path, children } = props;
  const { themeConfig } = (0, import_react.useContext)(import_context.ConfigContext);
  return /* @__PURE__ */ React.createElement(
    CardWrapper,
    {
      title: schema == null ? void 0 : schema.title,
      size: "small",
      "data-primary": themeConfig.colorPrimary
    },
    /* @__PURE__ */ React.createElement(import_antd.Row, { style: { marginTop: "24px" }, gutter: 18 }, children ? children : renderCore({
      schema: schema.properties,
      rootPath: [...rootPath, path]
    }))
  );
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
